@@ -7,8 +7,15 @@ use crate::{
 use sha2::{Digest, Sha512};
 use std::process::exit;
 
-pub fn print_mode_yubi(pass: &String,slot:u8) {
-    let key = yubi::get_hash(&pass,slot).expect("Failed to calculate hash from Yubikey"); // Get encryption key
+pub fn print_mode_yubi(pass: &String, slot: u8) {
+    let key = yubi::get_hash(&pass, slot); // Get encryption key
+    let key = match key {
+        Ok(key) => key,
+        Err(error) => {
+            eprintln!("Error: Failed to calculate hash from Yubikey\n{}", error);
+            exit(1)
+        }
+    };
     println!("{}", &key);
     exit(0);
 }
@@ -23,19 +30,15 @@ pub fn print_mode_file(pass: &String, file: &String, port: u16) {
     exit(0);
 }
 
-pub fn unlock_zfs_yubi(pass: String, zfspath: String,slot:u8) {
-    let key = yubi::get_hash(&pass,slot); // Get encryption key
-    let mut zfspath = zfspath;
+pub fn unlock_zfs_yubi(pass: String, zfspath: String, slot: u8) {
+    let key = yubi::get_hash(&pass, slot); // Get encryption key
     match key {
-        Ok(key) => {
-            if zfspath.ends_with("/") {
-                zfspath.pop();
-                zfs_mount(&key, zfspath.to_string());
-            } else {
-                zfs_mount(&key, zfspath)
-            }
-        } // Print encryption key
-        Err(error) => panic!("{}", error),
+        Ok(key) => zfs_mount(&key, zfspath),
+
+        Err(error) => {
+            eprintln!("Error: Failed to calculate hash from Yubikey\n{}", error);
+            exit(1)
+        }
     }
 }
 
@@ -66,19 +69,14 @@ pub fn create_zfs_file(pass: String, file: String, dataset: String, port: u16) {
     zfs_create(&key, dataset)
 }
 
-pub fn create_zfs_yubi(pass: String, zfspath: String,slot:u8) {
-    let key = yubi::get_hash(&pass,slot); // Get encryption key
-    let mut zfspath = zfspath;
+pub fn create_zfs_yubi(pass: String, zfspath: String, slot: u8) {
+    let key = yubi::get_hash(&pass, slot); // Get encryption key
+    let zfspath = zfspath;
     match key {
-        Ok(key) => {
-            if zfspath.ends_with("/") {
-                zfspath.pop();
-                zfs_create(&key, zfspath.to_string());
-            } else {
-                zfs_create(&key, zfspath)
-            }
-        } // Print encryption key
-        Err(error) => panic!("{}", error),
+        Ok(key) => zfs_create(&key, zfspath),
+        Err(error) => {
+            eprintln!("Error: Failed to calculate hash from Yubikey\n{}", error);
+            exit(1)
+        }
     }
 }
-
