@@ -4,6 +4,8 @@ mod logic;
 mod yubi;
 mod zfs;
 
+use std::process::exit;
+
 use crate::logic::{print_mode_file, print_mode_yubi, unlock_zfs_file, unlock_zfs_yubi};
 use crate::{
     logic::{create_zfs_file, create_zfs_yubi},
@@ -14,9 +16,16 @@ use sha2::{Digest, Sha512};
 
 fn main() {
     let args = Sargs::new();
-    let mut pass =
-        rpassword::prompt_password_stderr("Dataset Password: ").expect("Failed to get Password");
-    pass.push_str("shavee"); // Salt password
+    let pass = rpassword::prompt_password_stderr("Dataset Password: ");
+    let mut pass = match pass {
+        Ok(pass) => pass,
+        Err(error) => {
+            eprintln!("Error: Failed to read Password");
+            eprintln!("Error: {}", error);
+            exit(1)
+        }
+    };
+    pass.push_str("shavee");
 
     match args.umode.as_str() {
         "yubikey" => match args.mode.as_str() {
