@@ -29,7 +29,7 @@ pub fn get_hash(pass: &String, slot: u8) -> Result<String, io::Error> {
             .expect("Failed to run HMAC Challenge on SLOT 2 of Yubikey"); // Perform HMAC challenge
         format!("{:x}", &Sha512::digest(&hmac_result.deref())) // Prepare and return encryption key as hex string
     } else {
-        let e = io::Error::new(io::ErrorKind::NotFound, "Yubikey not found");
+        let e = io::Error::new(io::ErrorKind::NotFound, "Error: Yubikey not found");
         return Err(e);
     })
 }
